import axios from 'axios'
import { MonthlyNews } from '../models/monthlyNews.model'
export class MonthlyNewsService {
  private readonly _apiUrl: string
  constructor() {
    this._apiUrl = 'https://localhost:1443/'
  }
  /**
   * Creates a quotation and header for selected month
   * @param date
   * @param header
   * @param quote
   */
  public createMonthlyReport = async (
    date: Date,
    header: string,
    quote: string,
    token: string
  ): Promise<void> => {
    try {
      await axios.post(
        `${this._apiUrl}api/admin/monthlyNews`,
        {
          month: date.getMonth(),
          year: date.getFullYear(),
          header: header,
          quote: quote,
        },
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
    } catch (e) {
      console.log(e)
    }
  }

  /**
   * Gets a quotation and header for selected month
   */
  public getSingleMonthlyReport = async (
    year: number,
    month: number,
    token: string
  ): Promise<MonthlyNews | any> => {
    try {
      const { data } = await axios.get(
        `${this._apiUrl}api/admin/monthlyNews/${year}/${month}`,
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
      return data as MonthlyNews
    } catch (e) {
      console.log('error', e)
      return
    }
  }
}
